@@ -1,7 +1,7 @@
 //muroar.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2012
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2013
  *
  *  This file is part of µRoar,
  *  a minimalist library to access a RoarAudio Sound Server.
@@ -23,6 +23,8 @@
 
 /* ckport options:
  * ckport: ignore-symbol: strcpy of target security   -- length is check before the function is called.
+ * ckport: ignore-symbol: atoi   of target security   -- returned by functions ensuring tailing \0.
+ * ckport: ignore-symbol: strdup of target security   -- Caller is enforced to pass valid buffer.
  */
 
 #include "muroar.h"
@@ -191,7 +193,6 @@ static int muroar_open_socket_bsd (const char * server) {
 
  memcpy((struct in_addr *)&(in.sin_addr), he->h_addr, sizeof(struct in_addr));
 
- // TODO: add support to set port to something non-default.
  in.sin_family = AF_INET;
  if ( object != NULL ) {
   in.sin_port   = htons(atoi(object));
@@ -242,8 +243,9 @@ static muroar_t muroar_open_socket (const char * server) {
 
 // Open Control connection
 muroar_t muroar_connect(const char * server, const char * name) {
- char   useraddr[80] = "/invalid";
+ char   useraddr[80] = MUROAR_INVALID;
  char * addr[] = {useraddr, MUROAR_GSOCK, MUROAR_HOST, "::" MUROAR_OBJECT, MUROAR_ABSTRACT, NULL};
+ const char * home;
  unsigned char buf[MUROAR_IOBUF];
  uint16_t tmpu16;
  uint16_t pid;
@@ -291,11 +293,17 @@ muroar_t muroar_connect(const char * server, const char * name) {
    return MUROAR_HANDLE_INVALID;
  } else {
   // build string for ~/.roar
-  snprintf(useraddr, sizeof(useraddr), "/%s/.roar", getenv("HOME"));
-  useraddr[sizeof(useraddr)-1] = 0;
+  home = getenv("HOME");
+  if ( home != NULL && home[0] == '/' && strlen(home) < (sizeof(useraddr) - 7) ) {
+   snprintf(useraddr, sizeof(useraddr), "%s/.roar", home);
+   useraddr[sizeof(useraddr)-1] = 0;
+  }
 
   // go thru list of possible defaults:
   for (i = 0; fh == MUROAR_HANDLE_INVALID && addr[i] != NULL; i++) {
+   if ( !strcmp(addr[i], MUROAR_INVALID) )
+    continue;
+
    fh = muroar_open_socket(addr[i]);
   }
 
